@@ -12,9 +12,9 @@ import tarfile
 from npm2deb import utils, templates
 from npm2deb.mapper import Mapper
 
-VERSION = '0.2.8'
-DEBHELPER = 10
-STANDARDS_VERSION = '4.1.1'
+VERSION = '0.3.0'
+DEBHELPER = 11
+STANDARDS_VERSION = '4.3.0'
 
 
 class Npm2Deb(object):
@@ -81,6 +81,8 @@ class Npm2Deb(object):
         self.create_dirs()
         self.create_examples()
         self.create_watch()
+        self.create_upstream_metadata()
+        self.create_gbp_conf()
         self.create_manpages()
         if not self.noclean:
             self.clean()
@@ -127,7 +129,7 @@ You may want fix first these issues:\n""")
 
         if self.upstream_watch:
             print("""
-*** Warning ***\nUsing fakeupstream to download npm dist tarballs, because upstream
+*** Warning ***\nUsing npmregistry to download npm dist tarballs, because upstream
 git repo is missing tags. Its better to ask upstream to tag their releases
 instead of using npm dist tarballs as dist tarballs may contain pre built files
 and may not include tests.\n""")
@@ -143,6 +145,7 @@ and may not include tests.\n""")
     def run_buildpackage(self):
         print("\nBuilding the binary package")
         _call('dpkg-source -b .', shell=True)
+        _call('rm -rf .gitignore .git* .travis.yml', shell=True)
         _call('dpkg-buildpackage', shell=True)
         # removing auto generated temporary files
         _call('debian/rules clean', shell=True)
@@ -181,7 +184,7 @@ and may not include tests.\n""")
                     _os.remove(filename)
 
     def create_manpages(self):
-        if not 'man' in self.json:
+        if 'man' not in self.json:
             return
         mans = self.json['man']
         if not isinstance(mans, (list, tuple)):
@@ -192,14 +195,20 @@ and may not include tests.\n""")
     def create_watch(self):
         args = {}
         args['debian_name'] = self.debian_name
-        args['dversionmangle'] = 's/\+(debian|dfsg|ds|deb)(\.\d+)?$//'
+        args['dversionmangle'] = 'auto'
         args['url'] = self.upstream_repo_url
         args['module'] = self.name
+        args['remodule'] = _re.sub(r'\@', r'\@', self.name)
+        args['modulename'] = _re.sub(r'.*/', r'', self.name)
         try:
             if self.upstream_repo_url.find('github') >= 0:
+                utils.debug(1, 'Found GitHub url')
                 content = utils.get_watch('github') % args
+            elif self.upstream_repo_url.find('gitlab') >= 0:
+                utils.debug(1, 'Found GitLab url')
+                content = utils.get_watch('gitlab') % args
             else:
-                # if not supported, got to fakeupstream
+                # if not supported, got to npmregistry
                 raise ValueError
 
             utils.create_debian_file('watch', content)
@@ -207,14 +216,31 @@ and may not include tests.\n""")
             uscan_info = self.test_uscan()
 
             if uscan_info[0] != 0:
+                utils.debug(1, 'Uscan failed, switching to npmregistry')
                 raise ValueError
 
         except ValueError:
             self.upstream_watch = True
-            content = utils.get_watch('fakeupstream') % args
-            content = _re.sub('\.\*=@.*/', '.*=', content)
+            content = utils.get_watch('npmregistry') % args
             utils.create_debian_file('watch', content)
 
+    def create_upstream_metadata(self):
+        args = {}
+        args['url'] = _re.sub(r'^git\+', '', self.upstream_repo_url)
+        args['module'] = self.name
+        if self.upstream_repo_url.find('github') >= 0:
+            content = utils.get_upstream_metadata('github') % args
+            utils.create_dir("debian/upstream")
+            utils.create_debian_file('upstream/metadata', content)
+        elif self.upstream_repo_url.find('gitlab') >= 0:
+            content = utils.get_upstream_metadata('gitlab') % args
+            utils.create_dir("debian/upstream")
+            utils.create_debian_file('upstream/metadata', content)
+
+    def create_gbp_conf(self):
+        content = utils.get_gbp_conf()
+        utils.create_debian_file('gbp.conf', content)
+
     def create_examples(self):
         if _os.path.isdir('examples'):
             content = 'examples/*'
@@ -330,10 +356,6 @@ and may not include tests.\n""")
         args = {}
         args['name'] = self.name
         args['debian_name'] = self.debian_name
-        control = utils.get_template('tests/control') % args
-        utils.create_debian_file("tests/control", control)
-        require = utils.get_template("tests/require") % args
-        utils.create_debian_file("tests/require", require)
 
     def create_base_debian(self):
         utils.debug(1, "creating debian files")
@@ -345,7 +367,7 @@ and may not include tests.\n""")
     def read_package_info(self):
         data = None
         name_is = None
-        if _re.match("^(http:\/\/|https:\/\/)", self.name):
+        if _re.match("^(http://|https://)", self.name):
             utils.debug(1, "reading json - opening url %s" % self.name)
             data = _urlopen(self.name).read().decode('utf-8')
             name_is = 'url'
@@ -509,10 +531,12 @@ and may not include tests.\n""")
                     if tmp:
                         result = tmp
                 else:
-                    url = _re.sub(r'^git@(.*):', r'http://\1/', url)
-                    url = _re.sub(r'^git://', 'http://', url)
+                    utils.debug(1, ("raw URL: %s" % url))
+                    url = _re.sub(r'^git.*?@(.*?):', r'https://\1/', url)
+                    url = _re.sub(r'^.*?(?:ssh|git).*?://(?:.*?\@)?', 'https://', url)
                     url = _re.sub(r'\.git$', '', url)
                     result = url
+                    utils.debug(1, ("https URL: %s" % url))
             else:
                 result = url
         self.upstream_repo_url = result
