@@ -1,5 +1,4 @@
 from argparse import ArgumentParser as _ArgumentParser
-from subprocess import call as _call
 import os as _os
 import sys as _sys
 
@@ -19,113 +18,133 @@ def main(argv=None):
     parser = _ArgumentParser(prog='npm2deb')
     parser.add_argument('-D', '--debug', type=int, help='set debug level')
     parser.add_argument(
-        '-v', '--version', action='version',
-        version='%(prog)s ' + _.VERSION)
+        '-v', '--version', action='version', version='%(prog)s ' + _.VERSION)
 
     subparsers = parser.add_subparsers(title='commands')
 
     parser_create = subparsers.add_parser(
-        'create',
-        help='create the debian files')
+        'create', help='create the debian files')
     parser_create.add_argument(
-        '-n', '--noclean', action="store_true",
-        default=False, help='do not remove files downloaded with npm')
+        '-n',
+        '--noclean',
+        action="store_true",
+        default=False,
+        help='do not remove files downloaded with npm')
     parser_create.add_argument(
-        '--debhelper', default=_.DEBHELPER,
+        '--debhelper',
+        default=_.DEBHELPER,
         help='specify debhelper version [default: %(default)s]')
     parser_create.add_argument(
-        '--standards-version', default=_.STANDARDS_VERSION,
+        '--standards-version',
+        default=_utils.get_latest_debian_standards_version(),
         help='set standards-version [default: %(default)s]')
     parser_create.add_argument(
-        '--upstream-author', default=None,
+        '--upstream-author',
+        default=None,
         help='set upstream author if not automatically recognized')
     parser_create.add_argument(
-        '--upstream-homepage', default=None,
+        '--upstream-homepage',
+        default=None,
         help='set upstream homepage if not automatically recognized')
     parser_create.add_argument(
-        '--upstream-license', default=None,
+        '--upstream-license',
+        default=None,
         help='set upstream license if not automatically recognized')
     parser_create.add_argument(
-        '--debian-license', default=None,
+        '--debian-license',
+        default=None,
         help='license used for debian files [default: the same of upstream]')
     parser_create.add_argument(
-        'node_module',
-        help='node module available via npm')
+        'node_module', help='node module available via npm')
     parser_create.set_defaults(func=create)
 
     parser_view = subparsers.add_parser(
-        'view',
-        help="a summary view of a node module")
+        'view', help="a summary view of a node module")
     parser_view.add_argument(
-        '-j', '--json', action="store_true",
-        default=False, help='print verbose information in json format')
+        '-j',
+        '--json',
+        action="store_true",
+        default=False,
+        help='print verbose information in json format')
     parser_view.add_argument(
-        'node_module',
-        help='node module available via npm')
+        'node_module', help='node module available via npm')
     parser_view.set_defaults(func=print_view)
 
     parser_depends = subparsers.add_parser(
-        'depends',
-        help='show module dependencies in npm and debian')
+        'depends', help='show module dependencies in npm and debian')
     parser_depends.add_argument(
-        '-r', '--recursive', action="store_true",
-        default=False, help='look for binary dependencies recursively')
+        '-r',
+        '--recursive',
+        action="store_true",
+        default=False,
+        help='look for binary dependencies recursively')
     parser_depends.add_argument(
-        '-f', '--force', action="store_true",
-        default=False, help='force inspection for modules already in debian')
+        '-f',
+        '--force',
+        action="store_true",
+        default=False,
+        help='force inspection for modules already in debian')
     parser_depends.add_argument(
-        '-b', '--binary', action="store_true",
-        default=False, help='show binary dependencies')
+        '-b',
+        '--binary',
+        action="store_true",
+        default=False,
+        help='show binary dependencies')
     parser_depends.add_argument(
-        '-B', '--builddeb', action="store_true",
-        default=False, help='show build dependencies')
+        '-B',
+        '--builddeb',
+        action="store_true",
+        default=False,
+        help='show build dependencies')
     parser_depends.add_argument(
-        'node_module',
-        help='node module available via npm')
+        'node_module', help='node module available via npm')
     parser_depends.set_defaults(func=show_dependencies)
 
     parser_rdepends = subparsers.add_parser(
-        'rdepends',
-        help='show the reverse dependencies for module')
+        'rdepends', help='show the reverse dependencies for module')
     parser_rdepends.add_argument(
-        'node_module',
-        help='node module available via npm')
+        'node_module', help='node module available via npm')
     parser_rdepends.set_defaults(func=show_reverse_dependencies)
 
     parser_search = subparsers.add_parser(
-        'search',
-        help="look for module in debian project")
+        'search', help="look for module in debian project")
     parser_search.add_argument(
-        '-b', '--bug', action="store_true",
-        default=False, help='search for existing bug in wnpp')
+        '-b',
+        '--bug',
+        action="store_true",
+        default=False,
+        help='search for existing bug in wnpp')
     parser_search.add_argument(
-        '-d', '--debian', action="store_true",
-        default=False, help='search for existing package in debian')
+        '-d',
+        '--debian',
+        action="store_true",
+        default=False,
+        help='search for existing package in debian')
     parser_search.add_argument(
-        '-r', '--repository', action="store_true",
-        default=False, help='search for existing repository in alioth')
+        '-r',
+        '--repository',
+        action="store_true",
+        default=False,
+        help='search for existing repository in alioth')
     parser_search.add_argument(
-        'node_module',
-        help='node module available via npm')
+        'node_module', help='node module available via npm')
     parser_search.set_defaults(func=search_for_module)
 
-    parser_itp = subparsers.add_parser(
-        'itp',
-        help="print a itp bug template")
+    parser_itp = subparsers.add_parser('itp', help="print a itp bug template")
     parser_itp.add_argument(
-        'node_module',
-        help='node module available via npm')
+        'node_module', help='node module available via npm')
     parser_itp.set_defaults(func=print_itp)
 
     parser_license = subparsers.add_parser(
-        'license',
-        help='print license template and exit')
+        'license', help='print license template and exit')
     parser_license.add_argument(
-        '-l', '--list', action="store_true",
-        default=False, help='show the available licenses')
+        '-l',
+        '--list',
+        action="store_true",
+        default=False,
+        help='show the available licenses')
     parser_license.add_argument(
-        'name', nargs='?',
-        help='the license name to show')
+        'name', nargs='?', help='the license name to show')
     parser_license.set_defaults(func=print_license)
 
     if len(argv) == 1:
@@ -168,9 +187,10 @@ def print_view(args):
         from json import dumps
         # print a clean version of json module
         json = npm2deb_instance.json
-        for key in ['time', 'versions', 'dist-tags', 'component',
-                    'users', 'time', 'maintainers', 'readmeFilename',
-                    'contributors', 'keywords']:
+        for key in [
+                'time', 'versions', 'dist-tags', 'component', 'users', 'time',
+                'maintainers', 'readmeFilename', 'contributors', 'keywords'
+        ]:
             if key in json:
                 del json[key]
         print(dumps(json, indent=4, sort_keys=True))
@@ -181,13 +201,15 @@ def print_view(args):
             attr_key = key
             if key == 'license' or key == 'version':
                 attr_key = 'upstream_%s' % key
-            print(formatted.format("%s:" % key.capitalize(),
-                  getattr(npm2deb_instance, attr_key, None)))
+            print(
+                formatted.format("%s:" % key.capitalize(),
+                                 getattr(npm2deb_instance, attr_key, None)))
 
         mapper = _Mapper.get_instance()
         pkg_info = mapper.get_debian_package(npm2deb_instance.name)
-        print(formatted.format("Debian:",
-                               "%s (%s)" % (pkg_info['repr'], pkg_info['suite'])))
+        print(
+            formatted.format(
+                "Debian:", "%s (%s)" % (pkg_info['repr'], pkg_info['suite'])))
 
         if mapper.has_warnings():
             print("")
@@ -201,8 +223,8 @@ def print_itp(args):
 def print_license(args, prefix=""):
     if args.list:
         licenses = sorted(_templates.LICENSES.keys())
-        print("%s Available licenses are: %s." %
-              (prefix, ', '.join(licenses).lower()))
+        print("%s Available licenses are: %s." % (prefix,
+                                                  ', '.join(licenses).lower()))
     else:
         if args.name is None:
             print("You have to specify a license name")
@@ -236,11 +258,9 @@ def show_dependencies(args):
             module_ver = npm2deb_instance.upstream_version
             module_deb = _Mapper.get_instance()\
                 .get_debian_package(module_name)["repr"]
-            _helper.print_formatted_dependency("%s (%s)" %
-                                              (module_name, module_ver),
-                                               module_deb)
-            _helper.search_for_dependencies(npm2deb_instance,
-                                            args.recursive,
+            _helper.print_formatted_dependency(
+                "%s (%s)" % (module_name, module_ver), module_deb)
+            _helper.search_for_dependencies(npm2deb_instance, args.recursive,
                                             args.force)
             print("")
         else:
@@ -299,5 +319,6 @@ def _show_mapper_warnings():
         mapper.show_warnings()
         print("")
 
+
 if __name__ == '__main__':
     main()
