@@ -56,25 +56,26 @@ def get_template(filename):
         result = _templates.RULES
     elif filename == 'wnpp':
         result = _templates.WNPP
-    elif filename == 'tests/control':
-        result = _templates.TESTS['control']
-    elif filename == 'tests/require':
-        result = _templates.TESTS['require']
     return result
 
 
 def get_watch(which):
-    if which == 'github':
-        return _templates.WATCH['github']
-    elif which == 'bitbucket':
-        return _templates.WATCH['bitbucket']
-    else:
-        return _templates.WATCH['fakeupstream']
+    return _templates.WATCH.get(which) or _templates.WATCH.get('npmregistry')
+
+
+def get_upstream_metadata(which):
+    return _templates.METADATA.get(which)
+
+
+def get_gbp_conf():
+    return _templates.GBPCONF
 
 
 def get_license(license):
     result = None
     name = license.lower().replace('-', '')
+    args = {}
+    args['name'] = license
     if name.startswith('gpl2'):
         result = _templates.LICENSES['GPL-2']
     elif name.startswith('gpl3'):
@@ -88,11 +89,11 @@ def get_license(license):
     elif name.startswith('expat'):
         result = _templates.LICENSES['Expat']
     elif name.startswith('bsd4'):
-        result = _templates.LICENSES['BSD-4-clause']
+        result = _templates.LICENSES['BSD-4-clause'] % args
     elif name.startswith('bsd2'):
-        result = _templates.LICENSES['BSD-2-clause']
+        result = _templates.LICENSES['BSD-2-clause'] % args
     elif name.startswith('bsd'):
-        result = _templates.LICENSES['BSD-3-clause']
+        result = _templates.LICENSES['BSD-3-clause'] % args
     elif name.startswith('artistic'):
         result = _templates.LICENSES['Artistic']
     elif name.startswith('apache'):
@@ -136,8 +137,13 @@ def create_dir(dir):
     except OSError as oserror:
         raise OSError("Error: directory %s already exists." % oserror.filename)
 
+
 def parse_name(name):
-    parts = name.partition('@')
+    parts = name.rpartition('@')
+    if parts[0] == '':
+        if parts[1] == '@':
+            return '@'+parts[2], parts[0]
+        return parts[2], parts[0]
     return parts[0], parts[2]
 
 
