@@ -136,20 +136,20 @@ class debian(unittest.TestCase):
         line = self._get_debfile_line('watch', '/tags')
         self.assertTrue(line is not None and len(line) > 0)
 
-    def test_watch_fakeupstream(self):
-        # must create a fakeupstream since we do not know about git url
+    def test_watch_npmregistry(self):
+        # must create a npmregistry since we do not know about git url
         n = Npm2Deb('yg-panache')
         n.create_base_debian()
         n.create_watch()
-        line = self._get_debfile_line('watch', '/fakeupstream')
+        line = self._get_debfile_line('watch', '/npmregistry')
         self.assertTrue(line is not None and len(line) > 0)
 
     def test_watch_github_with_no_tags(self):
-        # must fallback on fakeupstream if no tags in github
+        # must fallback on npmregistry if no tags in github
         n = Npm2Deb('security')
         n.create_base_debian()
         n.create_watch()
-        line = self._get_debfile_line('watch', '/fakeupstream')
+        line = self._get_debfile_line('watch', '/npmregistry')
         self.assertTrue(line is not None and len(line) > 0)
 
     def test_repository_defined_as_string(self):
@@ -179,6 +179,17 @@ class debian(unittest.TestCase):
         n.create_base_debian()
         n.create_control()
 
+    def test_parse_name(self):
+        n = Npm2Deb('jade@1.11.0')
+        self.assertEqual(n.name, "jade")
+        x = Npm2Deb('@ava/write-file-atomic')
+        self.assertEqual(x.name, '@ava/write-file-atomic')
+        y = Npm2Deb('@types/jquery@2.0.49')
+        self.assertEqual(y.name, '@types/jquery')
+        z = Npm2Deb('@types/jquery')
+        self.assertEqual(z.name, '@types/jquery')
+
+
 
 if __name__ == '__main__':
     unittest.main()
